/* object-cache.c generated by valac 0.15.1.20-908e, the Vala compiler
 * generated from object-cache.vala, do not modify */


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <gee.h>
#include <float.h>
#include <math.h>
#include <gobject/gvaluecollector.h>


#define TYPE_TEST_OBJECT (test_object_get_type ())
#define TEST_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEST_OBJECT, TestObject))
#define TEST_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEST_OBJECT, TestObjectClass))
#define IS_TEST_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEST_OBJECT))
#define IS_TEST_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEST_OBJECT))
#define TEST_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEST_OBJECT, TestObjectClass))

typedef struct _TestObject TestObject;
typedef struct _TestObjectClass TestObjectClass;
typedef struct _TestObjectPrivate TestObjectPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _ParamSpecTestObject ParamSpecTestObject;

#define TYPE_TEST_CACHE (test_cache_get_type ())
#define TEST_CACHE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEST_CACHE, TestCache))
#define TEST_CACHE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEST_CACHE, TestCacheClass))
#define IS_TEST_CACHE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEST_CACHE))
#define IS_TEST_CACHE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEST_CACHE))
#define TEST_CACHE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEST_CACHE, TestCacheClass))

typedef struct _TestCache TestCache;
typedef struct _TestCacheClass TestCacheClass;
typedef struct _TestCachePrivate TestCachePrivate;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))

#define TYPE_OBJECT_CACHE_TESTS (object_cache_tests_get_type ())
#define OBJECT_CACHE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OBJECT_CACHE_TESTS, ObjectCacheTests))
#define OBJECT_CACHE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OBJECT_CACHE_TESTS, ObjectCacheTestsClass))
#define IS_OBJECT_CACHE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OBJECT_CACHE_TESTS))
#define IS_OBJECT_CACHE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OBJECT_CACHE_TESTS))
#define OBJECT_CACHE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OBJECT_CACHE_TESTS, ObjectCacheTestsClass))

typedef struct _ObjectCacheTests ObjectCacheTests;
typedef struct _ObjectCacheTestsClass ObjectCacheTestsClass;
typedef struct _ObjectCacheTestsPrivate ObjectCacheTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block1Data Block1Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _test_object_unref0(var) ((var == NULL) ? NULL : (var = (test_object_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
typedef struct _Block5Data Block5Data;
typedef struct _Block6Data Block6Data;
typedef struct _Block7Data Block7Data;
typedef struct _Block8Data Block8Data;
typedef struct _Block9Data Block9Data;
typedef struct _Block10Data Block10Data;
typedef struct _Block11Data Block11Data;

struct _TestObject {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TestObjectPrivate * priv;
};

struct _TestObjectClass {
	GTypeClass parent_class;
	void (*finalize) (TestObject *self);
};

struct _TestObjectPrivate {
	gchar* _my_string;
	guint _my_int;
};

struct _ParamSpecTestObject {
	GParamSpec parent_instance;
};

struct _TestCache {
	FolksObjectCache parent_instance;
	TestCachePrivate * priv;
};

struct _TestCacheClass {
	FolksObjectCacheClass parent_class;
};

struct _ObjectCacheTests {
	FolksTestCase parent_instance;
	ObjectCacheTestsPrivate * priv;
};

struct _ObjectCacheTestsClass {
	FolksTestCaseClass parent_class;
};

struct _ObjectCacheTestsPrivate {
	GFile* _cache_dir;
};

struct _Block1Data {
	int _ref_count_;
	ObjectCacheTests * self;
	GMainLoop* main_loop;
	TestCache* cache;
};

struct _Block2Data {
	int _ref_count_;
	ObjectCacheTests * self;
	GMainLoop* main_loop;
	TestCache* cache;
};

struct _Block3Data {
	int _ref_count_;
	ObjectCacheTests * self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block4Data {
	int _ref_count_;
	ObjectCacheTests * self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block5Data {
	int _ref_count_;
	ObjectCacheTests * self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block6Data {
	int _ref_count_;
	ObjectCacheTests * self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block7Data {
	int _ref_count_;
	ObjectCacheTests * self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block8Data {
	int _ref_count_;
	ObjectCacheTests * self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block9Data {
	int _ref_count_;
	ObjectCacheTests * self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block10Data {
	int _ref_count_;
	ObjectCacheTests * self;
	GMainLoop* main_loop;
	TestCache* cache;
	GeeSet* new_obj_set;
};

struct _Block11Data {
	int _ref_count_;
	ObjectCacheTests * self;
	GMainLoop* main_loop;
	TestCache* cache;
	gint obj_count;
	GeeSet* new_obj_set;
};


static gpointer test_object_parent_class = NULL;
static gpointer test_cache_parent_class = NULL;
static gpointer object_cache_tests_parent_class = NULL;

gpointer test_object_ref (gpointer instance);
void test_object_unref (gpointer instance);
GParamSpec* param_spec_test_object (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_test_object (GValue* value, gpointer v_object);
void value_take_test_object (GValue* value, gpointer v_object);
gpointer value_get_test_object (const GValue* value);
GType test_object_get_type (void) G_GNUC_CONST;
#define TEST_OBJECT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_TEST_OBJECT, TestObjectPrivate))
enum  {
	TEST_OBJECT_DUMMY_PROPERTY
};
TestObject* test_object_new (const gchar* my_string, guint my_int);
TestObject* test_object_construct (GType object_type, const gchar* my_string, guint my_int);
void test_object_set_my_string (TestObject* self, const gchar* value);
void test_object_set_my_int (TestObject* self, guint value);
const gchar* test_object_get_my_string (TestObject* self);
guint test_object_get_my_int (TestObject* self);
static void test_object_finalize (TestObject* obj);
GType test_cache_get_type (void) G_GNUC_CONST;
enum  {
	TEST_CACHE_DUMMY_PROPERTY
};
TestCache* test_cache_new (const gchar* id);
TestCache* test_cache_construct (GType object_type, const gchar* id);
static GVariantType* test_cache_real_get_serialised_object_type (FolksObjectCache* base, guint8 object_version);
static guint8 test_cache_real_get_serialised_object_version (FolksObjectCache* base);
static GVariant* test_cache_real_serialise_object (FolksObjectCache* base, TestObject* obj);
static TestObject* test_cache_real_deserialise_object (FolksObjectCache* base, GVariant* variant, guint8 object_version);
GType object_cache_tests_get_type (void) G_GNUC_CONST;
#define OBJECT_CACHE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_OBJECT_CACHE_TESTS, ObjectCacheTestsPrivate))
enum  {
	OBJECT_CACHE_TESTS_DUMMY_PROPERTY
};
ObjectCacheTests* object_cache_tests_new (void);
ObjectCacheTests* object_cache_tests_construct (GType object_type);
void object_cache_tests_test_create (ObjectCacheTests* self);
static void _object_cache_tests_test_create_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_store_objects (ObjectCacheTests* self);
static void _object_cache_tests_test_store_objects_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_store_objects_empty (ObjectCacheTests* self);
static void _object_cache_tests_test_store_objects_empty_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_load_objects (ObjectCacheTests* self);
static void _object_cache_tests_test_load_objects_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_load_objects_empty (ObjectCacheTests* self);
static void _object_cache_tests_test_load_objects_empty_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_load_objects_nonexistent (ObjectCacheTests* self);
static void _object_cache_tests_test_load_objects_nonexistent_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_clear (ObjectCacheTests* self);
static void _object_cache_tests_test_clear_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_clear_empty (ObjectCacheTests* self);
static void _object_cache_tests_test_clear_empty_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_clear_nonexistent (ObjectCacheTests* self);
static void _object_cache_tests_test_clear_nonexistent_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_store_objects_cancellation (ObjectCacheTests* self);
static void _object_cache_tests_test_store_objects_cancellation_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_load_objects_cancellation (ObjectCacheTests* self);
static void _object_cache_tests_test_load_objects_cancellation_folks_test_case_test_method (gpointer self);
void object_cache_tests_test_stress (ObjectCacheTests* self);
static void _object_cache_tests_test_stress_folks_test_case_test_method (gpointer self);
static void object_cache_tests_real_set_up (FolksTestCase* base);
void _object_cache_tests_delete_cache_directory (ObjectCacheTests* self);
static void object_cache_tests_real_tear_down (FolksTestCase* base);
void _object_cache_tests_delete_directory (ObjectCacheTests* self, GFile* dir, GError** error);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (Block1Data* _data1_);
static void __lambda2_ (Block1Data* _data1_, GObject* o, GAsyncResult* r);
static void ___lambda2__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (Block2Data* _data2_);
static void __lambda3_ (Block2Data* _data2_, GObject* o, GAsyncResult* r);
static void ___lambda3__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (Block3Data* _data3_);
static void __lambda4_ (Block3Data* _data3_, GObject* o, GAsyncResult* r);
static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda5_ (Block3Data* _data3_, GObject* o, GAsyncResult* r);
static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (Block4Data* _data4_);
static void __lambda6_ (Block4Data* _data4_, GObject* o, GAsyncResult* r);
static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda7_ (Block4Data* _data4_, GObject* o, GAsyncResult* r);
static void ___lambda7__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (Block5Data* _data5_);
static void __lambda8_ (Block5Data* _data5_, GObject* o, GAsyncResult* r);
static void ___lambda8__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (Block6Data* _data6_);
static void __lambda9_ (Block6Data* _data6_, GObject* o, GAsyncResult* r);
static void ___lambda9__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda10_ (Block6Data* _data6_, GObject* o, GAsyncResult* r);
static void ___lambda10__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda11_ (Block6Data* _data6_, GObject* o, GAsyncResult* r);
static void ___lambda11__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (Block7Data* _data7_);
static void __lambda12_ (Block7Data* _data7_, GObject* o, GAsyncResult* r);
static void ___lambda12__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda13_ (Block7Data* _data7_, GObject* o, GAsyncResult* r);
static void ___lambda13__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda14_ (Block7Data* _data7_, GObject* o, GAsyncResult* r);
static void ___lambda14__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block8Data* block8_data_ref (Block8Data* _data8_);
static void block8_data_unref (Block8Data* _data8_);
static void __lambda15_ (Block8Data* _data8_, GObject* o, GAsyncResult* r);
static void ___lambda15__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda16_ (Block8Data* _data8_, GObject* o, GAsyncResult* r);
static void ___lambda16__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (Block9Data* _data9_);
static void __lambda17_ (Block9Data* _data9_, GObject* o, GAsyncResult* r);
static void ___lambda17__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda18_ (Block9Data* _data9_, GObject* o, GAsyncResult* r);
static void ___lambda18__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (Block10Data* _data10_);
static void __lambda19_ (Block10Data* _data10_, GObject* o, GAsyncResult* r);
static void ___lambda19__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda20_ (Block10Data* _data10_, GObject* o, GAsyncResult* r);
static void ___lambda20__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block11Data* block11_data_ref (Block11Data* _data11_);
static void block11_data_unref (Block11Data* _data11_);
static void __lambda21_ (Block11Data* _data11_, GObject* o, GAsyncResult* r);
static void ___lambda21__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda22_ (Block11Data* _data11_, GObject* o, GAsyncResult* r);
static void ___lambda22__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void object_cache_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


TestObject* test_object_construct (GType object_type, const gchar* my_string, guint my_int) {
	TestObject* self = NULL;
	const gchar* _tmp0_;
	guint _tmp1_;
#line 10 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (my_string != NULL, NULL);
#line 10 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = (TestObject*) g_type_create_instance (object_type);
#line 12 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = my_string;
#line 12 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	test_object_set_my_string (self, _tmp0_);
#line 13 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = my_int;
#line 13 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	test_object_set_my_int (self, _tmp1_);
#line 10 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return self;
#line 355 "object-cache.c"
}


TestObject* test_object_new (const gchar* my_string, guint my_int) {
#line 10 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return test_object_construct (TYPE_TEST_OBJECT, my_string, my_int);
#line 362 "object-cache.c"
}


const gchar* test_object_get_my_string (TestObject* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 7 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 7 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = self->priv->_my_string;
#line 7 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	result = _tmp0_;
#line 7 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return result;
#line 377 "object-cache.c"
}


void test_object_set_my_string (TestObject* self, const gchar* value) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 7 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 7 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = value;
#line 7 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 7 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_free0 (self->priv->_my_string);
#line 7 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self->priv->_my_string = _tmp1_;
#line 394 "object-cache.c"
}


guint test_object_get_my_int (TestObject* self) {
	guint result;
	guint _tmp0_;
#line 8 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 8 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = self->priv->_my_int;
#line 8 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	result = _tmp0_;
#line 8 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return result;
#line 409 "object-cache.c"
}


void test_object_set_my_int (TestObject* self, guint value) {
	guint _tmp0_;
#line 8 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 8 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = value;
#line 8 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self->priv->_my_int = _tmp0_;
#line 421 "object-cache.c"
}


static void value_test_object_init (GValue* value) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	value->data[0].v_pointer = NULL;
#line 428 "object-cache.c"
}


static void value_test_object_free_value (GValue* value) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (value->data[0].v_pointer) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		test_object_unref (value->data[0].v_pointer);
#line 437 "object-cache.c"
	}
}


static void value_test_object_copy_value (const GValue* src_value, GValue* dest_value) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (src_value->data[0].v_pointer) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		dest_value->data[0].v_pointer = test_object_ref (src_value->data[0].v_pointer);
#line 447 "object-cache.c"
	} else {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		dest_value->data[0].v_pointer = NULL;
#line 451 "object-cache.c"
	}
}


static gpointer value_test_object_peek_pointer (const GValue* value) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return value->data[0].v_pointer;
#line 459 "object-cache.c"
}


static gchar* value_test_object_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (collect_values[0].v_pointer) {
#line 466 "object-cache.c"
		TestObject* object;
		object = collect_values[0].v_pointer;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		if (object->parent_instance.g_class == NULL) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 473 "object-cache.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 477 "object-cache.c"
		}
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = test_object_ref (object);
#line 481 "object-cache.c"
	} else {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = NULL;
#line 485 "object-cache.c"
	}
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return NULL;
#line 489 "object-cache.c"
}


static gchar* value_test_object_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	TestObject** object_p;
	object_p = collect_values[0].v_pointer;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (!object_p) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 500 "object-cache.c"
	}
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (!value->data[0].v_pointer) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		*object_p = NULL;
#line 506 "object-cache.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		*object_p = value->data[0].v_pointer;
#line 510 "object-cache.c"
	} else {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		*object_p = test_object_ref (value->data[0].v_pointer);
#line 514 "object-cache.c"
	}
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return NULL;
#line 518 "object-cache.c"
}


GParamSpec* param_spec_test_object (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecTestObject* spec;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_TEST_OBJECT), NULL);
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return G_PARAM_SPEC (spec);
#line 532 "object-cache.c"
}


gpointer value_get_test_object (const GValue* value) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEST_OBJECT), NULL);
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return value->data[0].v_pointer;
#line 541 "object-cache.c"
}


void value_set_test_object (GValue* value, gpointer v_object) {
	TestObject* old;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEST_OBJECT));
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	old = value->data[0].v_pointer;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (v_object) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEST_OBJECT));
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = v_object;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		test_object_ref (value->data[0].v_pointer);
#line 561 "object-cache.c"
	} else {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = NULL;
#line 565 "object-cache.c"
	}
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (old) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		test_object_unref (old);
#line 571 "object-cache.c"
	}
}


void value_take_test_object (GValue* value, gpointer v_object) {
	TestObject* old;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEST_OBJECT));
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	old = value->data[0].v_pointer;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (v_object) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEST_OBJECT));
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = v_object;
#line 590 "object-cache.c"
	} else {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		value->data[0].v_pointer = NULL;
#line 594 "object-cache.c"
	}
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (old) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		test_object_unref (old);
#line 600 "object-cache.c"
	}
}


static void test_object_class_init (TestObjectClass * klass) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	test_object_parent_class = g_type_class_peek_parent (klass);
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	TEST_OBJECT_CLASS (klass)->finalize = test_object_finalize;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_type_class_add_private (klass, sizeof (TestObjectPrivate));
#line 612 "object-cache.c"
}


static void test_object_instance_init (TestObject * self) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self->priv = TEST_OBJECT_GET_PRIVATE (self);
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self->ref_count = 1;
#line 621 "object-cache.c"
}


static void test_object_finalize (TestObject* obj) {
	TestObject * self;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = TEST_OBJECT (obj);
#line 7 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_free0 (self->priv->_my_string);
#line 631 "object-cache.c"
}


GType test_object_get_type (void) {
	static volatile gsize test_object_type_id__volatile = 0;
	if (g_once_init_enter (&test_object_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_test_object_init, value_test_object_free_value, value_test_object_copy_value, value_test_object_peek_pointer, "p", value_test_object_collect_value, "p", value_test_object_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (TestObjectClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) test_object_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TestObject), 0, (GInstanceInitFunc) test_object_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType test_object_type_id;
		test_object_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TestObject", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&test_object_type_id__volatile, test_object_type_id);
	}
	return test_object_type_id__volatile;
}


gpointer test_object_ref (gpointer instance) {
	TestObject* self;
	self = instance;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&self->ref_count);
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return instance;
#line 656 "object-cache.c"
}


void test_object_unref (gpointer instance) {
	TestObject* self;
	self = instance;
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		TEST_OBJECT_GET_CLASS (self)->finalize (self);
#line 5 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 669 "object-cache.c"
	}
}


TestCache* test_cache_construct (GType object_type, const gchar* id) {
	TestCache * self = NULL;
	const gchar* _tmp0_;
#line 19 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (id != NULL, NULL);
#line 21 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = id;
#line 21 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = (TestCache*) folks_object_cache_construct (object_type, TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, "test", _tmp0_);
#line 19 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return self;
#line 685 "object-cache.c"
}


TestCache* test_cache_new (const gchar* id) {
#line 19 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return test_cache_construct (TYPE_TEST_CACHE, id);
#line 692 "object-cache.c"
}


static gpointer _g_variant_type_copy0 (gpointer self) {
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return self ? g_variant_type_copy (self) : NULL;
#line 699 "object-cache.c"
}


static GVariantType* test_cache_real_get_serialised_object_type (FolksObjectCache* base, guint8 object_version) {
	TestCache * self;
	GVariantType* result = NULL;
	const GVariantType* _tmp0_;
	GVariantType* _tmp1_;
	const GVariantType* _tmp2_;
	GVariantType* _tmp3_;
	GVariantType** _tmp4_ = NULL;
	GVariantType** _tmp5_;
	gint _tmp5__length1;
	GVariantType* _tmp6_;
	GVariantType* _tmp7_;
#line 24 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = (TestCache*) base;
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = G_VARIANT_TYPE_STRING;
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = _g_variant_type_copy0 (_tmp0_);
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = G_VARIANT_TYPE_UINT32;
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = _g_variant_type_copy0 (_tmp2_);
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = g_new0 (GVariantType*, 2 + 1);
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_[0] = _tmp1_;
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_[1] = _tmp3_;
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = _tmp4_;
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp5__length1 = 2;
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = g_variant_type_new_tuple (_tmp5_, 2);
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = _tmp6_;
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_variant_type_free), NULL);
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	result = _tmp7_;
#line 27 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return result;
#line 745 "object-cache.c"
}


static guint8 test_cache_real_get_serialised_object_version (FolksObjectCache* base) {
	TestCache * self;
	guint8 result = 0U;
#line 33 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = (TestCache*) base;
#line 35 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	result = (guint8) 1;
#line 35 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return result;
#line 758 "object-cache.c"
}


static GVariant* test_cache_real_serialise_object (FolksObjectCache* base, TestObject* obj) {
	TestCache * self;
	GVariant* result = NULL;
	TestObject* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	GVariant* _tmp3_;
	GVariant* _tmp4_;
	TestObject* _tmp5_;
	guint _tmp6_;
	guint _tmp7_;
	GVariant* _tmp8_;
	GVariant* _tmp9_;
	GVariant** _tmp10_ = NULL;
	GVariant** _tmp11_;
	gint _tmp11__length1;
	GVariant* _tmp12_;
	GVariant* _tmp13_;
	GVariant* _tmp14_;
#line 38 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = (TestCache*) base;
#line 38 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (obj != NULL, NULL);
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = obj;
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_object_get_my_string (_tmp0_);
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _tmp1_;
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = g_variant_new_string (_tmp2_);
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = g_variant_ref_sink (_tmp3_);
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = obj;
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = test_object_get_my_int (_tmp5_);
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = _tmp6_;
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp8_ = g_variant_new_uint32 ((guint32) _tmp7_);
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp9_ = g_variant_ref_sink (_tmp8_);
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp10_ = g_new0 (GVariant*, 2 + 1);
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp10_[0] = _tmp4_;
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp10_[1] = _tmp9_;
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp11_ = _tmp10_;
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp11__length1 = 2;
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp12_ = g_variant_new_tuple (_tmp11_, 2);
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp13_ = g_variant_ref_sink (_tmp12_);
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp14_ = _tmp13_;
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp11_ = (_vala_array_free (_tmp11_, _tmp11__length1, (GDestroyNotify) g_variant_unref), NULL);
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	result = _tmp14_;
#line 40 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return result;
#line 827 "object-cache.c"
}


static TestObject* test_cache_real_deserialise_object (FolksObjectCache* base, GVariant* variant, guint8 object_version) {
	TestCache * self;
	TestObject* result = NULL;
	GVariant* _tmp0_;
	GVariant* _tmp1_ = NULL;
	GVariant* _tmp2_;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* my_string;
	GVariant* _tmp6_;
	GVariant* _tmp7_ = NULL;
	GVariant* _tmp8_;
	guint32 _tmp9_ = 0U;
	guint32 _tmp10_;
	guint32 my_int;
	TestObject* _tmp11_;
#line 46 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = (TestCache*) base;
#line 46 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_val_if_fail (variant != NULL, NULL);
#line 50 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = variant;
#line 50 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = g_variant_get_child_value (_tmp0_, (gsize) 0);
#line 50 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _tmp1_;
#line 50 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = g_variant_get_string (_tmp2_, NULL);
#line 50 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 50 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = _tmp4_;
#line 50 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_variant_unref0 (_tmp2_);
#line 50 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	my_string = _tmp5_;
#line 51 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = variant;
#line 51 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = g_variant_get_child_value (_tmp6_, (gsize) 1);
#line 51 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp8_ = _tmp7_;
#line 51 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp9_ = g_variant_get_uint32 (_tmp8_);
#line 51 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp10_ = _tmp9_;
#line 51 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_variant_unref0 (_tmp8_);
#line 51 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	my_int = _tmp10_;
#line 53 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp11_ = test_object_new (my_string, (guint) my_int);
#line 53 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	result = _tmp11_;
#line 53 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_free0 (my_string);
#line 53 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return result;
#line 890 "object-cache.c"
}


static void test_cache_class_init (TestCacheClass * klass) {
#line 17 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	test_cache_parent_class = g_type_class_peek_parent (klass);
#line 17 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	FOLKS_OBJECT_CACHE_CLASS (klass)->get_serialised_object_type = test_cache_real_get_serialised_object_type;
#line 17 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	FOLKS_OBJECT_CACHE_CLASS (klass)->get_serialised_object_version = test_cache_real_get_serialised_object_version;
#line 17 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	FOLKS_OBJECT_CACHE_CLASS (klass)->serialise_object = test_cache_real_serialise_object;
#line 17 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	FOLKS_OBJECT_CACHE_CLASS (klass)->deserialise_object = test_cache_real_deserialise_object;
#line 905 "object-cache.c"
}


static void test_cache_instance_init (TestCache * self) {
}


GType test_cache_get_type (void) {
	static volatile gsize test_cache_type_id__volatile = 0;
	if (g_once_init_enter (&test_cache_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TestCacheClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) test_cache_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TestCache), 0, (GInstanceInitFunc) test_cache_instance_init, NULL };
		GType test_cache_type_id;
		test_cache_type_id = g_type_register_static (FOLKS_TYPE_OBJECT_CACHE, "TestCache", &g_define_type_info, 0);
		g_once_init_leave (&test_cache_type_id__volatile, test_cache_type_id);
	}
	return test_cache_type_id__volatile;
}


static void _object_cache_tests_test_create_folks_test_case_test_method (gpointer self) {
#line 72 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_create (self);
#line 928 "object-cache.c"
}


static void _object_cache_tests_test_store_objects_folks_test_case_test_method (gpointer self) {
#line 73 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_store_objects (self);
#line 935 "object-cache.c"
}


static void _object_cache_tests_test_store_objects_empty_folks_test_case_test_method (gpointer self) {
#line 74 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_store_objects_empty (self);
#line 942 "object-cache.c"
}


static void _object_cache_tests_test_load_objects_folks_test_case_test_method (gpointer self) {
#line 75 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_load_objects (self);
#line 949 "object-cache.c"
}


static void _object_cache_tests_test_load_objects_empty_folks_test_case_test_method (gpointer self) {
#line 76 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_load_objects_empty (self);
#line 956 "object-cache.c"
}


static void _object_cache_tests_test_load_objects_nonexistent_folks_test_case_test_method (gpointer self) {
#line 77 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_load_objects_nonexistent (self);
#line 963 "object-cache.c"
}


static void _object_cache_tests_test_clear_folks_test_case_test_method (gpointer self) {
#line 79 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_clear (self);
#line 970 "object-cache.c"
}


static void _object_cache_tests_test_clear_empty_folks_test_case_test_method (gpointer self) {
#line 80 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_clear_empty (self);
#line 977 "object-cache.c"
}


static void _object_cache_tests_test_clear_nonexistent_folks_test_case_test_method (gpointer self) {
#line 81 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_clear_nonexistent (self);
#line 984 "object-cache.c"
}


static void _object_cache_tests_test_store_objects_cancellation_folks_test_case_test_method (gpointer self) {
#line 84 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_store_objects_cancellation (self);
#line 991 "object-cache.c"
}


static void _object_cache_tests_test_load_objects_cancellation_folks_test_case_test_method (gpointer self) {
#line 86 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_load_objects_cancellation (self);
#line 998 "object-cache.c"
}


static void _object_cache_tests_test_stress_folks_test_case_test_method (gpointer self) {
#line 90 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_test_stress (self);
#line 1005 "object-cache.c"
}


ObjectCacheTests* object_cache_tests_construct (GType object_type) {
	ObjectCacheTests * self = NULL;
	const gchar* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_;
	GFile* _tmp3_ = NULL;
#line 64 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = (ObjectCacheTests*) folks_test_case_construct (object_type, "ObjectCache");
#line 67 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_get_tmp_dir ();
#line 67 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = g_file_new_for_path (_tmp0_);
#line 67 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _tmp1_;
#line 67 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = g_file_get_child (_tmp2_, "folks-object-cache-tests");
#line 67 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (self->priv->_cache_dir);
#line 67 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self->priv->_cache_dir = _tmp3_;
#line 67 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_tmp2_);
#line 72 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "create", _object_cache_tests_test_create_folks_test_case_test_method, self);
#line 73 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "store-objects", _object_cache_tests_test_store_objects_folks_test_case_test_method, self);
#line 74 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "store-objects-empty", _object_cache_tests_test_store_objects_empty_folks_test_case_test_method, self);
#line 75 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "load-objects", _object_cache_tests_test_load_objects_folks_test_case_test_method, self);
#line 76 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "load-objects-empty", _object_cache_tests_test_load_objects_empty_folks_test_case_test_method, self);
#line 77 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "load-objects-nonexistent", _object_cache_tests_test_load_objects_nonexistent_folks_test_case_test_method, self);
#line 79 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "clear", _object_cache_tests_test_clear_folks_test_case_test_method, self);
#line 80 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "clear-empty", _object_cache_tests_test_clear_empty_folks_test_case_test_method, self);
#line 81 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "clear-nonexistent", _object_cache_tests_test_clear_nonexistent_folks_test_case_test_method, self);
#line 84 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "store-objects-cancellation", _object_cache_tests_test_store_objects_cancellation_folks_test_case_test_method, self);
#line 86 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "load-objects-cancellation", _object_cache_tests_test_load_objects_cancellation_folks_test_case_test_method, self);
#line 90 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "stress", _object_cache_tests_test_stress_folks_test_case_test_method, self);
#line 62 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return self;
#line 1057 "object-cache.c"
}


ObjectCacheTests* object_cache_tests_new (void) {
#line 62 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return object_cache_tests_construct (TYPE_OBJECT_CACHE_TESTS);
#line 1064 "object-cache.c"
}


static void object_cache_tests_real_set_up (FolksTestCase* base) {
	ObjectCacheTests * self;
	GFile* _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_;
#line 93 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = (ObjectCacheTests*) base;
#line 95 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_object_cache_tests_delete_cache_directory (self);
#line 96 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = self->priv->_cache_dir;
#line 96 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = g_file_get_path (_tmp0_);
#line 96 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _tmp1_;
#line 96 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_setenv ("XDG_CACHE_HOME", _tmp2_, TRUE);
#line 96 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_free0 (_tmp2_);
#line 1087 "object-cache.c"
}


static void object_cache_tests_real_tear_down (FolksTestCase* base) {
	ObjectCacheTests * self;
#line 100 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = (ObjectCacheTests*) base;
#line 102 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_object_cache_tests_delete_cache_directory (self);
#line 1097 "object-cache.c"
}


void _object_cache_tests_delete_directory (ObjectCacheTests* self, GFile* dir, GError** error) {
	GFile* _tmp0_;
	GFileEnumerator* _tmp1_ = NULL;
	GFileEnumerator* enumerator;
	GFileEnumerator* _tmp2_;
	GFileInfo* _tmp3_ = NULL;
	GFileInfo* file_info;
	GFileEnumerator* _tmp16_;
	GFile* _tmp17_;
	GError * _inner_error_ = NULL;
#line 105 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 105 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (dir != NULL);
#line 108 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = dir;
#line 108 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = g_file_enumerate_children (_tmp0_, G_FILE_ATTRIBUTE_STANDARD_NAME, G_FILE_QUERY_INFO_NONE, NULL, &_inner_error_);
#line 108 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	enumerator = _tmp1_;
#line 108 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (_inner_error_ != NULL) {
#line 108 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_propagate_error (error, _inner_error_);
#line 108 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		return;
#line 1127 "object-cache.c"
	}
#line 112 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = enumerator;
#line 112 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = g_file_enumerator_next_file (_tmp2_, NULL, &_inner_error_);
#line 112 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	file_info = _tmp3_;
#line 112 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (_inner_error_ != NULL) {
#line 112 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_propagate_error (error, _inner_error_);
#line 112 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (enumerator);
#line 112 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		return;
#line 1143 "object-cache.c"
	}
#line 113 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	while (TRUE) {
#line 1147 "object-cache.c"
		GFileInfo* _tmp4_;
		GFile* _tmp5_;
		GFileInfo* _tmp6_;
		const gchar* _tmp7_ = NULL;
		GFile* _tmp8_ = NULL;
		GFile* child_file;
		GFile* _tmp9_;
		GFileType _tmp10_ = 0;
		GFileEnumerator* _tmp13_;
		GFileInfo* _tmp14_ = NULL;
		GFileInfo* _tmp15_;
#line 113 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp4_ = file_info;
#line 113 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		if (!(_tmp4_ != NULL)) {
#line 113 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			break;
#line 1165 "object-cache.c"
		}
#line 115 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp5_ = dir;
#line 115 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp6_ = file_info;
#line 115 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp7_ = g_file_info_get_name (_tmp6_);
#line 115 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp8_ = g_file_get_child (_tmp5_, _tmp7_);
#line 115 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		child_file = _tmp8_;
#line 117 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp9_ = child_file;
#line 117 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp10_ = g_file_query_file_type (_tmp9_, G_FILE_QUERY_INFO_NONE, NULL);
#line 117 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		if (_tmp10_ == G_FILE_TYPE_DIRECTORY) {
#line 1183 "object-cache.c"
			GFile* _tmp11_;
#line 120 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_tmp11_ = child_file;
#line 120 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_object_cache_tests_delete_directory (self, _tmp11_, &_inner_error_);
#line 120 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			if (_inner_error_ != NULL) {
#line 120 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				g_propagate_error (error, _inner_error_);
#line 120 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (child_file);
#line 120 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (file_info);
#line 120 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (enumerator);
#line 120 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				return;
#line 1201 "object-cache.c"
			}
		} else {
			GFile* _tmp12_;
#line 124 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_tmp12_ = child_file;
#line 124 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			g_file_delete (_tmp12_, NULL, &_inner_error_);
#line 124 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			if (_inner_error_ != NULL) {
#line 124 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				g_propagate_error (error, _inner_error_);
#line 124 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (child_file);
#line 124 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (file_info);
#line 124 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (enumerator);
#line 124 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				return;
#line 1221 "object-cache.c"
			}
		}
#line 127 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp13_ = enumerator;
#line 127 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp14_ = g_file_enumerator_next_file (_tmp13_, NULL, &_inner_error_);
#line 127 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp15_ = _tmp14_;
#line 127 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		if (_inner_error_ != NULL) {
#line 127 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			g_propagate_error (error, _inner_error_);
#line 127 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_g_object_unref0 (child_file);
#line 127 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_g_object_unref0 (file_info);
#line 127 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_g_object_unref0 (enumerator);
#line 127 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			return;
#line 1242 "object-cache.c"
		}
#line 127 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (file_info);
#line 127 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		file_info = _tmp15_;
#line 113 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (child_file);
#line 1250 "object-cache.c"
	}
#line 129 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp16_ = enumerator;
#line 129 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_file_enumerator_close (_tmp16_, NULL, &_inner_error_);
#line 129 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (_inner_error_ != NULL) {
#line 129 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_propagate_error (error, _inner_error_);
#line 129 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (file_info);
#line 129 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (enumerator);
#line 129 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		return;
#line 1266 "object-cache.c"
	}
#line 132 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp17_ = dir;
#line 132 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_file_delete (_tmp17_, NULL, &_inner_error_);
#line 132 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (_inner_error_ != NULL) {
#line 132 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_propagate_error (error, _inner_error_);
#line 132 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (file_info);
#line 132 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (enumerator);
#line 132 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		return;
#line 1282 "object-cache.c"
	}
#line 105 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (file_info);
#line 105 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (enumerator);
#line 1288 "object-cache.c"
}


void _object_cache_tests_delete_cache_directory (ObjectCacheTests* self) {
	GError * _inner_error_ = NULL;
#line 135 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 1296 "object-cache.c"
	{
		GFile* _tmp0_;
#line 139 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp0_ = self->priv->_cache_dir;
#line 139 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_object_cache_tests_delete_directory (self, _tmp0_, &_inner_error_);
#line 139 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		if (_inner_error_ != NULL) {
#line 1305 "object-cache.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
#line 137 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		e = _inner_error_;
#line 137 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_inner_error_ = NULL;
#line 137 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_error_free0 (e);
#line 1319 "object-cache.c"
	}
	__finally0:
#line 137 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (_inner_error_ != NULL) {
#line 137 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 137 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_clear_error (&_inner_error_);
#line 137 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		return;
#line 1330 "object-cache.c"
	}
}


void object_cache_tests_test_create (ObjectCacheTests* self) {
	TestCache* _tmp0_;
	TestCache* cache;
#line 147 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 150 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = test_cache_new ("test-create");
#line 150 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	cache = _tmp0_;
#line 152 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (cache != NULL);
#line 147 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (cache);
#line 1348 "object-cache.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _data1_;
#line 1357 "object-cache.c"
}


static void block1_data_unref (Block1Data* _data1_) {
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 1364 "object-cache.c"
		ObjectCacheTests * self;
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		self = _data1_->self;
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data1_->cache);
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data1_->main_loop);
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block1Data, _data1_);
#line 1376 "object-cache.c"
	}
}


static void __lambda2_ (Block1Data* _data1_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
#line 166 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data1_->self;
#line 166 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 168 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 168 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data1_->cache, _tmp0_);
#line 169 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data1_->main_loop);
#line 1394 "object-cache.c"
}


static void ___lambda2__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 166 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda2_ (self, source_object, res);
#line 166 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block1_data_unref (self);
#line 1403 "object-cache.c"
}


void object_cache_tests_test_store_objects (ObjectCacheTests* self) {
	Block1Data* _data1_;
	GMainLoop* _tmp0_;
	TestCache* _tmp1_;
	GeeHashSet* _tmp2_;
	GeeHashSet* obj_set;
	TestObject* _tmp3_;
	TestObject* _tmp4_;
	TestObject* _tmp5_;
	TestObject* _tmp6_;
	TestObject* _tmp7_;
	TestObject* _tmp8_;
	TestObject* _tmp9_;
	TestObject* _tmp10_;
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data1_->_ref_count_ = 1;
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data1_->self = g_object_ref (self);
#line 157 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 157 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data1_->main_loop = _tmp0_;
#line 158 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-store-objects");
#line 158 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data1_->cache = _tmp1_;
#line 160 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL);
#line 160 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp2_;
#line 161 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = test_object_new ("Foo", (guint) 1);
#line 161 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = _tmp3_;
#line 161 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp4_);
#line 161 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp4_);
#line 162 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = test_object_new ("Bar", (guint) 2);
#line 162 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = _tmp5_;
#line 162 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp6_);
#line 162 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp6_);
#line 163 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = test_object_new ("De", (guint) 3);
#line 163 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp8_ = _tmp7_;
#line 163 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp8_);
#line 163 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp8_);
#line 164 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp9_ = test_object_new ("Baz", (guint) 4);
#line 164 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp10_ = _tmp9_;
#line 164 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp10_);
#line 164 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp10_);
#line 166 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data1_->cache, (GeeSet*) obj_set, NULL, ___lambda2__gasync_ready_callback, block1_data_ref (_data1_));
#line 172 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data1_->main_loop);
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block1_data_unref (_data1_);
#line 155 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data1_ = NULL;
#line 1483 "object-cache.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _data2_;
#line 1492 "object-cache.c"
}


static void block2_data_unref (Block2Data* _data2_) {
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1499 "object-cache.c"
		ObjectCacheTests * self;
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		self = _data2_->self;
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data2_->cache);
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data2_->main_loop);
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block2Data, _data2_);
#line 1511 "object-cache.c"
	}
}


static void __lambda3_ (Block2Data* _data2_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
#line 180 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data2_->self;
#line 180 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 182 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 182 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data2_->cache, _tmp0_);
#line 183 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data2_->main_loop);
#line 1529 "object-cache.c"
}


static void ___lambda3__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 180 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda3_ (self, source_object, res);
#line 180 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block2_data_unref (self);
#line 1538 "object-cache.c"
}


void object_cache_tests_test_store_objects_empty (ObjectCacheTests* self) {
	Block2Data* _data2_;
	GMainLoop* _tmp0_;
	TestCache* _tmp1_;
	GeeHashSet* _tmp2_;
	GeeHashSet* _tmp3_;
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data2_->_ref_count_ = 1;
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data2_->self = g_object_ref (self);
#line 177 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 177 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data2_->main_loop = _tmp0_;
#line 178 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-store-objects-empty");
#line 178 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data2_->cache = _tmp1_;
#line 180 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL);
#line 180 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = _tmp2_;
#line 180 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data2_->cache, (GeeSet*) _tmp3_, NULL, ___lambda3__gasync_ready_callback, block2_data_ref (_data2_));
#line 180 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_tmp3_);
#line 186 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data2_->main_loop);
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block2_data_unref (_data2_);
#line 175 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data2_ = NULL;
#line 1578 "object-cache.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _data3_;
#line 1587 "object-cache.c"
}


static void block3_data_unref (Block3Data* _data3_) {
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 1594 "object-cache.c"
		ObjectCacheTests * self;
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		self = _data3_->self;
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data3_->new_obj_set);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data3_->cache);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data3_->main_loop);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block3Data, _data3_);
#line 1608 "object-cache.c"
	}
}


static void __lambda4_ (Block3Data* _data3_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	TestCache* _tmp0_;
	GAsyncResult* _tmp1_;
	GMainLoop* _tmp2_;
#line 203 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data3_->self;
#line 203 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 205 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = _data3_->cache;
#line 205 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = r;
#line 205 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _tmp0_, _tmp1_);
#line 206 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _data3_->main_loop;
#line 206 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_tmp2_);
#line 1632 "object-cache.c"
}


static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 203 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda4_ (self, source_object, res);
#line 203 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block3_data_unref (self);
#line 1641 "object-cache.c"
}


static void __lambda5_ (Block3Data* _data3_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	TestCache* _tmp0_;
	GAsyncResult* _tmp1_;
	GeeSet* _tmp2_ = NULL;
	GMainLoop* _tmp3_;
#line 213 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data3_->self;
#line 213 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 215 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = _data3_->cache;
#line 215 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = r;
#line 215 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _tmp0_, _tmp1_);
#line 215 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data3_->new_obj_set);
#line 215 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data3_->new_obj_set = _tmp2_;
#line 216 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = _data3_->main_loop;
#line 216 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_tmp3_);
#line 1669 "object-cache.c"
}


static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 213 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda5_ (self, source_object, res);
#line 213 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block3_data_unref (self);
#line 1678 "object-cache.c"
}


void object_cache_tests_test_load_objects (ObjectCacheTests* self) {
	Block3Data* _data3_;
	GMainLoop* _tmp0_;
	TestCache* _tmp1_;
	TestObject* _tmp2_;
	TestObject* obj1;
	TestObject* _tmp3_;
	TestObject* obj2;
	GeeHashSet* _tmp4_;
	GeeHashSet* obj_set;
	GeeHashSet* _tmp5_;
	TestObject* _tmp6_;
	GeeHashSet* _tmp7_;
	TestObject* _tmp8_;
	TestCache* _tmp9_;
	GeeHashSet* _tmp10_;
	GMainLoop* _tmp11_;
	TestCache* _tmp12_;
	GMainLoop* _tmp13_;
	GeeSet* _tmp14_;
	GeeSet* _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	GeeHashSet* _tmp18_;
	gint _tmp19_;
	gint _tmp20_;
	GeeHashSet* _tmp50_;
	gint _tmp51_;
	gint _tmp52_;
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data3_->_ref_count_ = 1;
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data3_->self = g_object_ref (self);
#line 191 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 191 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data3_->main_loop = _tmp0_;
#line 192 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-load-objects");
#line 192 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data3_->cache = _tmp1_;
#line 195 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = test_object_new ("Foo", (guint) 1);
#line 195 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj1 = _tmp2_;
#line 196 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = test_object_new ("Bar", (guint) 2);
#line 196 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj2 = _tmp3_;
#line 198 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL);
#line 198 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp4_;
#line 199 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = obj_set;
#line 199 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = obj1;
#line 199 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, _tmp6_);
#line 200 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = obj_set;
#line 200 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp8_ = obj2;
#line 200 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp7_, _tmp8_);
#line 203 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp9_ = _data3_->cache;
#line 203 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp10_ = obj_set;
#line 203 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _tmp9_, (GeeSet*) _tmp10_, NULL, ___lambda4__gasync_ready_callback, block3_data_ref (_data3_));
#line 209 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp11_ = _data3_->main_loop;
#line 209 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_tmp11_);
#line 212 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data3_->new_obj_set = NULL;
#line 213 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp12_ = _data3_->cache;
#line 213 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _tmp12_, NULL, ___lambda5__gasync_ready_callback, block3_data_ref (_data3_));
#line 219 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp13_ = _data3_->main_loop;
#line 219 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_tmp13_);
#line 222 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp14_ = _data3_->new_obj_set;
#line 222 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_tmp14_ != NULL);
#line 223 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp15_ = _data3_->new_obj_set;
#line 223 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp16_ = gee_collection_get_size ((GeeCollection*) _tmp15_);
#line 223 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp17_ = _tmp16_;
#line 223 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp18_ = obj_set;
#line 223 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp19_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp18_);
#line 223 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp20_ = _tmp19_;
#line 223 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_tmp17_ == _tmp20_);
#line 1789 "object-cache.c"
	{
		GeeSet* _tmp21_;
		GeeIterator* _tmp22_ = NULL;
		GeeIterator* _new_obj_it;
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp21_ = _data3_->new_obj_set;
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_new_obj_it = _tmp22_;
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		while (TRUE) {
#line 1802 "object-cache.c"
			GeeIterator* _tmp23_;
			gboolean _tmp24_ = FALSE;
			GeeIterator* _tmp25_;
			gpointer _tmp26_ = NULL;
			TestObject* new_obj;
			gboolean partner_found;
			gboolean _tmp49_;
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_tmp23_ = _new_obj_it;
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_tmp24_ = gee_iterator_next (_tmp23_);
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			if (!_tmp24_) {
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				break;
#line 1818 "object-cache.c"
			}
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_tmp25_ = _new_obj_it;
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_tmp26_ = gee_iterator_get (_tmp25_);
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			new_obj = (TestObject*) _tmp26_;
#line 227 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			partner_found = FALSE;
#line 1828 "object-cache.c"
			{
				GeeHashSet* _tmp27_;
				GeeIterator* _tmp28_ = NULL;
				GeeIterator* _original_obj_it;
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_tmp27_ = obj_set;
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_tmp28_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp27_);
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_original_obj_it = _tmp28_;
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				while (TRUE) {
#line 1841 "object-cache.c"
					GeeIterator* _tmp29_;
					gboolean _tmp30_ = FALSE;
					GeeIterator* _tmp31_;
					gpointer _tmp32_ = NULL;
					TestObject* original_obj;
					gboolean _tmp33_ = FALSE;
					TestObject* _tmp34_;
					const gchar* _tmp35_;
					const gchar* _tmp36_;
					TestObject* _tmp37_;
					const gchar* _tmp38_;
					const gchar* _tmp39_;
					gboolean _tmp46_;
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp29_ = _original_obj_it;
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp30_ = gee_iterator_next (_tmp29_);
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					if (!_tmp30_) {
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						break;
#line 1863 "object-cache.c"
					}
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp31_ = _original_obj_it;
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp32_ = gee_iterator_get (_tmp31_);
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					original_obj = (TestObject*) _tmp32_;
#line 231 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp34_ = new_obj;
#line 231 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp35_ = test_object_get_my_string (_tmp34_);
#line 231 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp36_ = _tmp35_;
#line 231 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp37_ = original_obj;
#line 231 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp38_ = test_object_get_my_string (_tmp37_);
#line 231 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp39_ = _tmp38_;
#line 231 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					if (g_strcmp0 (_tmp36_, _tmp39_) == 0) {
#line 1885 "object-cache.c"
						TestObject* _tmp40_;
						guint _tmp41_;
						guint _tmp42_;
						TestObject* _tmp43_;
						guint _tmp44_;
						guint _tmp45_;
#line 232 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						_tmp40_ = new_obj;
#line 232 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						_tmp41_ = test_object_get_my_int (_tmp40_);
#line 232 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						_tmp42_ = _tmp41_;
#line 232 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						_tmp43_ = original_obj;
#line 232 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						_tmp44_ = test_object_get_my_int (_tmp43_);
#line 232 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						_tmp45_ = _tmp44_;
#line 232 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						_tmp33_ = _tmp42_ == _tmp45_;
#line 1906 "object-cache.c"
					} else {
#line 231 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						_tmp33_ = FALSE;
#line 1910 "object-cache.c"
					}
#line 231 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp46_ = _tmp33_;
#line 231 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					if (_tmp46_) {
#line 1916 "object-cache.c"
						GeeHashSet* _tmp47_;
						TestObject* _tmp48_;
#line 234 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						_tmp47_ = obj_set;
#line 234 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						_tmp48_ = original_obj;
#line 234 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp47_, _tmp48_);
#line 235 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						partner_found = TRUE;
#line 236 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						_test_object_unref0 (original_obj);
#line 236 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
						break;
#line 1931 "object-cache.c"
					}
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_test_object_unref0 (original_obj);
#line 1935 "object-cache.c"
				}
#line 229 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_g_object_unref0 (_original_obj_it);
#line 1939 "object-cache.c"
			}
#line 240 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_tmp49_ = partner_found;
#line 240 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			g_assert (_tmp49_);
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_test_object_unref0 (new_obj);
#line 1947 "object-cache.c"
		}
#line 225 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_new_obj_it);
#line 1951 "object-cache.c"
	}
#line 243 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp50_ = obj_set;
#line 243 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp51_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp50_);
#line 243 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp52_ = _tmp51_;
#line 243 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_tmp52_ == 0);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj2);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj1);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block3_data_unref (_data3_);
#line 189 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data3_ = NULL;
#line 1971 "object-cache.c"
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _data4_;
#line 1980 "object-cache.c"
}


static void block4_data_unref (Block4Data* _data4_) {
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 1987 "object-cache.c"
		ObjectCacheTests * self;
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		self = _data4_->self;
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data4_->new_obj_set);
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data4_->cache);
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data4_->main_loop);
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block4Data, _data4_);
#line 2001 "object-cache.c"
	}
}


static void __lambda6_ (Block4Data* _data4_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
#line 252 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data4_->self;
#line 252 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 254 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 254 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data4_->cache, _tmp0_);
#line 255 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data4_->main_loop);
#line 2019 "object-cache.c"
}


static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 252 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda6_ (self, source_object, res);
#line 252 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block4_data_unref (self);
#line 2028 "object-cache.c"
}


static void __lambda7_ (Block4Data* _data4_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
	GeeSet* _tmp1_ = NULL;
#line 262 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data4_->self;
#line 262 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 264 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 264 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data4_->cache, _tmp0_);
#line 264 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data4_->new_obj_set);
#line 264 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data4_->new_obj_set = _tmp1_;
#line 265 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data4_->main_loop);
#line 2050 "object-cache.c"
}


static void ___lambda7__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 262 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda7_ (self, source_object, res);
#line 262 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block4_data_unref (self);
#line 2059 "object-cache.c"
}


void object_cache_tests_test_load_objects_empty (ObjectCacheTests* self) {
	Block4Data* _data4_;
	GMainLoop* _tmp0_;
	TestCache* _tmp1_;
	GeeHashSet* _tmp2_;
	GeeHashSet* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data4_ = g_slice_new0 (Block4Data);
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data4_->_ref_count_ = 1;
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data4_->self = g_object_ref (self);
#line 248 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 248 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data4_->main_loop = _tmp0_;
#line 249 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-load-objects-empty");
#line 249 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data4_->cache = _tmp1_;
#line 252 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL);
#line 252 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = _tmp2_;
#line 252 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data4_->cache, (GeeSet*) _tmp3_, NULL, ___lambda6__gasync_ready_callback, block4_data_ref (_data4_));
#line 252 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_tmp3_);
#line 258 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data4_->main_loop);
#line 261 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data4_->new_obj_set = NULL;
#line 262 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data4_->cache, NULL, ___lambda7__gasync_ready_callback, block4_data_ref (_data4_));
#line 268 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data4_->main_loop);
#line 271 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_data4_->new_obj_set != NULL);
#line 272 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = gee_collection_get_size ((GeeCollection*) _data4_->new_obj_set);
#line 272 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = _tmp4_;
#line 272 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_tmp5_ == 0);
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block4_data_unref (_data4_);
#line 246 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data4_ = NULL;
#line 2115 "object-cache.c"
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _data5_;
#line 2124 "object-cache.c"
}


static void block5_data_unref (Block5Data* _data5_) {
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 2131 "object-cache.c"
		ObjectCacheTests * self;
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		self = _data5_->self;
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data5_->new_obj_set);
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data5_->cache);
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data5_->main_loop);
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block5Data, _data5_);
#line 2145 "object-cache.c"
	}
}


static void __lambda8_ (Block5Data* _data5_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
	GeeSet* _tmp1_ = NULL;
#line 285 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data5_->self;
#line 285 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 287 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 287 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data5_->cache, _tmp0_);
#line 287 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data5_->new_obj_set);
#line 287 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data5_->new_obj_set = _tmp1_;
#line 288 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data5_->main_loop);
#line 2168 "object-cache.c"
}


static void ___lambda8__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 285 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda8_ (self, source_object, res);
#line 285 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block5_data_unref (self);
#line 2177 "object-cache.c"
}


void object_cache_tests_test_load_objects_nonexistent (ObjectCacheTests* self) {
	Block5Data* _data5_;
	GMainLoop* _tmp0_;
	TestCache* _tmp1_;
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data5_ = g_slice_new0 (Block5Data);
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data5_->_ref_count_ = 1;
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data5_->self = g_object_ref (self);
#line 277 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 277 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data5_->main_loop = _tmp0_;
#line 278 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-load-objects-nonexistent");
#line 278 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data5_->cache = _tmp1_;
#line 281 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_object_cache_tests_delete_cache_directory (self);
#line 284 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data5_->new_obj_set = NULL;
#line 285 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data5_->cache, NULL, ___lambda8__gasync_ready_callback, block5_data_ref (_data5_));
#line 291 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data5_->main_loop);
#line 294 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_data5_->new_obj_set == NULL);
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block5_data_unref (_data5_);
#line 275 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data5_ = NULL;
#line 2215 "object-cache.c"
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data6_->_ref_count_);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _data6_;
#line 2224 "object-cache.c"
}


static void block6_data_unref (Block6Data* _data6_) {
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
#line 2231 "object-cache.c"
		ObjectCacheTests * self;
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		self = _data6_->self;
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data6_->new_obj_set);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data6_->cache);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data6_->main_loop);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block6Data, _data6_);
#line 2245 "object-cache.c"
	}
}


static void __lambda9_ (Block6Data* _data6_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
#line 311 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data6_->self;
#line 311 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 313 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 313 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data6_->cache, _tmp0_);
#line 314 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data6_->main_loop);
#line 2263 "object-cache.c"
}


static void ___lambda9__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 311 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda9_ (self, source_object, res);
#line 311 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block6_data_unref (self);
#line 2272 "object-cache.c"
}


static void __lambda10_ (Block6Data* _data6_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
#line 320 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data6_->self;
#line 320 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 322 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 322 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache_finish ((FolksObjectCache*) _data6_->cache, _tmp0_);
#line 323 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data6_->main_loop);
#line 2289 "object-cache.c"
}


static void ___lambda10__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 320 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda10_ (self, source_object, res);
#line 320 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block6_data_unref (self);
#line 2298 "object-cache.c"
}


static void __lambda11_ (Block6Data* _data6_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
	GeeSet* _tmp1_ = NULL;
#line 330 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data6_->self;
#line 330 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 332 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 332 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data6_->cache, _tmp0_);
#line 332 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data6_->new_obj_set);
#line 332 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data6_->new_obj_set = _tmp1_;
#line 333 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data6_->main_loop);
#line 2320 "object-cache.c"
}


static void ___lambda11__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 330 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda11_ (self, source_object, res);
#line 330 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block6_data_unref (self);
#line 2329 "object-cache.c"
}


void object_cache_tests_test_clear (ObjectCacheTests* self) {
	Block6Data* _data6_;
	GMainLoop* _tmp0_;
	TestCache* _tmp1_;
	TestObject* _tmp2_;
	TestObject* obj1;
	TestObject* _tmp3_;
	TestObject* obj2;
	GeeHashSet* _tmp4_;
	GeeHashSet* obj_set;
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data6_ = g_slice_new0 (Block6Data);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data6_->_ref_count_ = 1;
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data6_->self = g_object_ref (self);
#line 299 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 299 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data6_->main_loop = _tmp0_;
#line 300 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-clear");
#line 300 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data6_->cache = _tmp1_;
#line 303 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = test_object_new ("Foo", (guint) 1);
#line 303 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj1 = _tmp2_;
#line 304 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = test_object_new ("Bar", (guint) 2);
#line 304 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj2 = _tmp3_;
#line 306 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL);
#line 306 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp4_;
#line 307 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, obj1);
#line 308 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, obj2);
#line 311 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data6_->cache, (GeeSet*) obj_set, NULL, ___lambda9__gasync_ready_callback, block6_data_ref (_data6_));
#line 317 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data6_->main_loop);
#line 320 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache ((FolksObjectCache*) _data6_->cache, ___lambda10__gasync_ready_callback, block6_data_ref (_data6_));
#line 326 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data6_->main_loop);
#line 329 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data6_->new_obj_set = NULL;
#line 330 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data6_->cache, NULL, ___lambda11__gasync_ready_callback, block6_data_ref (_data6_));
#line 336 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data6_->main_loop);
#line 338 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_data6_->new_obj_set == NULL);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj2);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj1);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block6_data_unref (_data6_);
#line 297 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data6_ = NULL;
#line 2401 "object-cache.c"
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _data7_;
#line 2410 "object-cache.c"
}


static void block7_data_unref (Block7Data* _data7_) {
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 2417 "object-cache.c"
		ObjectCacheTests * self;
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		self = _data7_->self;
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data7_->new_obj_set);
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data7_->cache);
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data7_->main_loop);
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block7Data, _data7_);
#line 2431 "object-cache.c"
	}
}


static void __lambda12_ (Block7Data* _data7_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
#line 347 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data7_->self;
#line 347 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 349 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 349 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data7_->cache, _tmp0_);
#line 350 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data7_->main_loop);
#line 2449 "object-cache.c"
}


static void ___lambda12__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 347 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda12_ (self, source_object, res);
#line 347 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block7_data_unref (self);
#line 2458 "object-cache.c"
}


static void __lambda13_ (Block7Data* _data7_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
#line 356 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data7_->self;
#line 356 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 358 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 358 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache_finish ((FolksObjectCache*) _data7_->cache, _tmp0_);
#line 359 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data7_->main_loop);
#line 2475 "object-cache.c"
}


static void ___lambda13__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 356 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda13_ (self, source_object, res);
#line 356 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block7_data_unref (self);
#line 2484 "object-cache.c"
}


static void __lambda14_ (Block7Data* _data7_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
	GeeSet* _tmp1_ = NULL;
#line 366 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data7_->self;
#line 366 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 368 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 368 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data7_->cache, _tmp0_);
#line 368 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data7_->new_obj_set);
#line 368 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data7_->new_obj_set = _tmp1_;
#line 369 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data7_->main_loop);
#line 2506 "object-cache.c"
}


static void ___lambda14__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 366 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda14_ (self, source_object, res);
#line 366 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block7_data_unref (self);
#line 2515 "object-cache.c"
}


void object_cache_tests_test_clear_empty (ObjectCacheTests* self) {
	Block7Data* _data7_;
	GMainLoop* _tmp0_;
	TestCache* _tmp1_;
	GeeHashSet* _tmp2_;
	GeeHashSet* _tmp3_;
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data7_ = g_slice_new0 (Block7Data);
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data7_->_ref_count_ = 1;
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data7_->self = g_object_ref (self);
#line 343 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 343 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data7_->main_loop = _tmp0_;
#line 344 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-clear-empty");
#line 344 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data7_->cache = _tmp1_;
#line 347 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL);
#line 347 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = _tmp2_;
#line 347 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data7_->cache, (GeeSet*) _tmp3_, NULL, ___lambda12__gasync_ready_callback, block7_data_ref (_data7_));
#line 347 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_tmp3_);
#line 353 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data7_->main_loop);
#line 356 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache ((FolksObjectCache*) _data7_->cache, ___lambda13__gasync_ready_callback, block7_data_ref (_data7_));
#line 362 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data7_->main_loop);
#line 365 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data7_->new_obj_set = NULL;
#line 366 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data7_->cache, NULL, ___lambda14__gasync_ready_callback, block7_data_ref (_data7_));
#line 372 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data7_->main_loop);
#line 374 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_data7_->new_obj_set == NULL);
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block7_data_unref (_data7_);
#line 341 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data7_ = NULL;
#line 2567 "object-cache.c"
}


static Block8Data* block8_data_ref (Block8Data* _data8_) {
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data8_->_ref_count_);
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _data8_;
#line 2576 "object-cache.c"
}


static void block8_data_unref (Block8Data* _data8_) {
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data8_->_ref_count_)) {
#line 2583 "object-cache.c"
		ObjectCacheTests * self;
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		self = _data8_->self;
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data8_->new_obj_set);
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data8_->cache);
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data8_->main_loop);
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block8Data, _data8_);
#line 2597 "object-cache.c"
	}
}


static void __lambda15_ (Block8Data* _data8_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
#line 386 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data8_->self;
#line 386 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 388 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 388 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache_finish ((FolksObjectCache*) _data8_->cache, _tmp0_);
#line 389 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data8_->main_loop);
#line 2615 "object-cache.c"
}


static void ___lambda15__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 386 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda15_ (self, source_object, res);
#line 386 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block8_data_unref (self);
#line 2624 "object-cache.c"
}


static void __lambda16_ (Block8Data* _data8_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
	GeeSet* _tmp1_ = NULL;
#line 396 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data8_->self;
#line 396 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 398 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 398 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data8_->cache, _tmp0_);
#line 398 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data8_->new_obj_set);
#line 398 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data8_->new_obj_set = _tmp1_;
#line 399 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data8_->main_loop);
#line 2646 "object-cache.c"
}


static void ___lambda16__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 396 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda16_ (self, source_object, res);
#line 396 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block8_data_unref (self);
#line 2655 "object-cache.c"
}


void object_cache_tests_test_clear_nonexistent (ObjectCacheTests* self) {
	Block8Data* _data8_;
	GMainLoop* _tmp0_;
	TestCache* _tmp1_;
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data8_ = g_slice_new0 (Block8Data);
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data8_->_ref_count_ = 1;
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data8_->self = g_object_ref (self);
#line 379 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 379 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data8_->main_loop = _tmp0_;
#line 380 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-clear-nonexistent");
#line 380 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data8_->cache = _tmp1_;
#line 383 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_object_cache_tests_delete_cache_directory (self);
#line 386 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_clear_cache ((FolksObjectCache*) _data8_->cache, ___lambda15__gasync_ready_callback, block8_data_ref (_data8_));
#line 392 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data8_->main_loop);
#line 395 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data8_->new_obj_set = NULL;
#line 396 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data8_->cache, NULL, ___lambda16__gasync_ready_callback, block8_data_ref (_data8_));
#line 402 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data8_->main_loop);
#line 404 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_data8_->new_obj_set == NULL);
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block8_data_unref (_data8_);
#line 377 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data8_ = NULL;
#line 2697 "object-cache.c"
}


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _data9_;
#line 2706 "object-cache.c"
}


static void block9_data_unref (Block9Data* _data9_) {
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 2713 "object-cache.c"
		ObjectCacheTests * self;
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		self = _data9_->self;
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data9_->new_obj_set);
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data9_->cache);
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data9_->main_loop);
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block9Data, _data9_);
#line 2727 "object-cache.c"
	}
}


static void __lambda17_ (Block9Data* _data9_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
#line 420 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data9_->self;
#line 420 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 422 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 422 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data9_->cache, _tmp0_);
#line 423 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data9_->main_loop);
#line 2745 "object-cache.c"
}


static void ___lambda17__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 420 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda17_ (self, source_object, res);
#line 420 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block9_data_unref (self);
#line 2754 "object-cache.c"
}


static void __lambda18_ (Block9Data* _data9_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
	GeeSet* _tmp1_ = NULL;
#line 432 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data9_->self;
#line 432 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 434 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 434 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data9_->cache, _tmp0_);
#line 434 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data9_->new_obj_set);
#line 434 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data9_->new_obj_set = _tmp1_;
#line 435 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data9_->main_loop);
#line 2776 "object-cache.c"
}


static void ___lambda18__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 432 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda18_ (self, source_object, res);
#line 432 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block9_data_unref (self);
#line 2785 "object-cache.c"
}


void object_cache_tests_test_store_objects_cancellation (ObjectCacheTests* self) {
	Block9Data* _data9_;
	GMainLoop* _tmp0_;
	TestCache* _tmp1_;
	GeeHashSet* _tmp2_;
	GeeHashSet* obj_set;
	TestObject* _tmp3_;
	TestObject* _tmp4_;
	TestObject* _tmp5_;
	TestObject* _tmp6_;
	TestObject* _tmp7_;
	TestObject* _tmp8_;
	TestObject* _tmp9_;
	TestObject* _tmp10_;
	GCancellable* _tmp11_;
	GCancellable* cancellable;
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data9_ = g_slice_new0 (Block9Data);
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data9_->_ref_count_ = 1;
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data9_->self = g_object_ref (self);
#line 409 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 409 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data9_->main_loop = _tmp0_;
#line 410 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-store-objects-cancellation");
#line 410 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data9_->cache = _tmp1_;
#line 412 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL);
#line 412 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp2_;
#line 413 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = test_object_new ("Foo", (guint) 1);
#line 413 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = _tmp3_;
#line 413 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp4_);
#line 413 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp4_);
#line 414 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = test_object_new ("Bar", (guint) 2);
#line 414 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp6_ = _tmp5_;
#line 414 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp6_);
#line 414 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp6_);
#line 415 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp7_ = test_object_new ("De", (guint) 3);
#line 415 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp8_ = _tmp7_;
#line 415 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp8_);
#line 415 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp8_);
#line 416 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp9_ = test_object_new ("Baz", (guint) 4);
#line 416 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp10_ = _tmp9_;
#line 416 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, _tmp10_);
#line 416 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (_tmp10_);
#line 418 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp11_ = g_cancellable_new ();
#line 418 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	cancellable = _tmp11_;
#line 420 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data9_->cache, (GeeSet*) obj_set, cancellable, ___lambda17__gasync_ready_callback, block9_data_ref (_data9_));
#line 427 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_cancellable_cancel (cancellable);
#line 428 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data9_->main_loop);
#line 431 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data9_->new_obj_set = NULL;
#line 432 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data9_->cache, NULL, ___lambda18__gasync_ready_callback, block9_data_ref (_data9_));
#line 438 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data9_->main_loop);
#line 440 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_data9_->new_obj_set == NULL);
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (cancellable);
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block9_data_unref (_data9_);
#line 407 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data9_ = NULL;
#line 2883 "object-cache.c"
}


static Block10Data* block10_data_ref (Block10Data* _data10_) {
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data10_->_ref_count_);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _data10_;
#line 2892 "object-cache.c"
}


static void block10_data_unref (Block10Data* _data10_) {
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
#line 2899 "object-cache.c"
		ObjectCacheTests * self;
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		self = _data10_->self;
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data10_->new_obj_set);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data10_->cache);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data10_->main_loop);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block10Data, _data10_);
#line 2913 "object-cache.c"
	}
}


static void __lambda19_ (Block10Data* _data10_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
#line 457 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data10_->self;
#line 457 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 459 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 459 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _data10_->cache, _tmp0_);
#line 460 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data10_->main_loop);
#line 2931 "object-cache.c"
}


static void ___lambda19__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 457 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda19_ (self, source_object, res);
#line 457 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block10_data_unref (self);
#line 2940 "object-cache.c"
}


static void __lambda20_ (Block10Data* _data10_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	GAsyncResult* _tmp0_;
	GeeSet* _tmp1_ = NULL;
#line 469 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data10_->self;
#line 469 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 471 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = r;
#line 471 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _data10_->cache, _tmp0_);
#line 471 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data10_->new_obj_set);
#line 471 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data10_->new_obj_set = _tmp1_;
#line 472 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_data10_->main_loop);
#line 2962 "object-cache.c"
}


static void ___lambda20__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 469 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda20_ (self, source_object, res);
#line 469 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block10_data_unref (self);
#line 2971 "object-cache.c"
}


void object_cache_tests_test_load_objects_cancellation (ObjectCacheTests* self) {
	Block10Data* _data10_;
	GMainLoop* _tmp0_;
	TestCache* _tmp1_;
	TestObject* _tmp2_;
	TestObject* obj1;
	TestObject* _tmp3_;
	TestObject* obj2;
	GeeHashSet* _tmp4_;
	GeeHashSet* obj_set;
	GCancellable* _tmp5_;
	GCancellable* cancellable;
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data10_ = g_slice_new0 (Block10Data);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data10_->_ref_count_ = 1;
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data10_->self = g_object_ref (self);
#line 445 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 445 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data10_->main_loop = _tmp0_;
#line 446 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-load-objects-cancellation");
#line 446 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data10_->cache = _tmp1_;
#line 449 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = test_object_new ("Foo", (guint) 1);
#line 449 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj1 = _tmp2_;
#line 450 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = test_object_new ("Bar", (guint) 2);
#line 450 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj2 = _tmp3_;
#line 452 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL);
#line 452 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp4_;
#line 453 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, obj1);
#line 454 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) obj_set, obj2);
#line 457 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _data10_->cache, (GeeSet*) obj_set, NULL, ___lambda19__gasync_ready_callback, block10_data_ref (_data10_));
#line 463 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data10_->main_loop);
#line 466 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = g_cancellable_new ();
#line 466 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	cancellable = _tmp5_;
#line 468 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data10_->new_obj_set = NULL;
#line 469 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _data10_->cache, cancellable, ___lambda20__gasync_ready_callback, block10_data_ref (_data10_));
#line 476 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_cancellable_cancel (cancellable);
#line 477 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_data10_->main_loop);
#line 479 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_data10_->new_obj_set == NULL);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (cancellable);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj2);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_test_object_unref0 (obj1);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block10_data_unref (_data10_);
#line 443 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data10_ = NULL;
#line 3049 "object-cache.c"
}


static Block11Data* block11_data_ref (Block11Data* _data11_) {
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_atomic_int_inc (&_data11_->_ref_count_);
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _data11_;
#line 3058 "object-cache.c"
}


static void block11_data_unref (Block11Data* _data11_) {
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	if (g_atomic_int_dec_and_test (&_data11_->_ref_count_)) {
#line 3065 "object-cache.c"
		ObjectCacheTests * self;
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		self = _data11_->self;
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data11_->new_obj_set);
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (_data11_->cache);
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_main_loop_unref0 (_data11_->main_loop);
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		_g_object_unref0 (self);
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		g_slice_free (Block11Data, _data11_);
#line 3079 "object-cache.c"
	}
}


static void __lambda21_ (Block11Data* _data11_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	gdouble _tmp0_ = 0.0;
	gdouble elapsed_time;
	gint _tmp1_;
	TestCache* _tmp2_;
	GAsyncResult* _tmp3_;
	GMainLoop* _tmp4_;
#line 499 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data11_->self;
#line 499 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 501 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_test_timer_elapsed ();
#line 501 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	elapsed_time = _tmp0_;
#line 502 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = _data11_->obj_count;
#line 502 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_message ("object-cache.vala:502: Storing %u objects in a cache file took %f seco" \
"nds.", (guint) _tmp1_, elapsed_time);
#line 505 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _data11_->cache;
#line 505 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = r;
#line 505 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects_finish ((FolksObjectCache*) _tmp2_, _tmp3_);
#line 506 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = _data11_->main_loop;
#line 506 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_tmp4_);
#line 3114 "object-cache.c"
}


static void ___lambda21__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 499 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda21_ (self, source_object, res);
#line 499 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block11_data_unref (self);
#line 3123 "object-cache.c"
}


static void __lambda22_ (Block11Data* _data11_, GObject* o, GAsyncResult* r) {
	ObjectCacheTests * self;
	gdouble _tmp0_ = 0.0;
	gdouble elapsed_time;
	gint _tmp1_;
	TestCache* _tmp2_;
	GAsyncResult* _tmp3_;
	GeeSet* _tmp4_ = NULL;
	GMainLoop* _tmp5_;
#line 515 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = _data11_->self;
#line 515 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (r != NULL);
#line 517 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_test_timer_elapsed ();
#line 517 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	elapsed_time = _tmp0_;
#line 518 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = _data11_->obj_count;
#line 518 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_message ("object-cache.vala:518: Loading %u objects from a cache file took %f se" \
"conds.", (guint) _tmp1_, elapsed_time);
#line 521 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _data11_->cache;
#line 521 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = r;
#line 521 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp4_ = folks_object_cache_load_objects_finish ((FolksObjectCache*) _tmp2_, _tmp3_);
#line 521 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_data11_->new_obj_set);
#line 521 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data11_->new_obj_set = _tmp4_;
#line 522 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp5_ = _data11_->main_loop;
#line 522 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_quit (_tmp5_);
#line 3162 "object-cache.c"
}


static void ___lambda22__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 515 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	__lambda22_ (self, source_object, res);
#line 515 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block11_data_unref (self);
#line 3171 "object-cache.c"
}


void object_cache_tests_test_stress (ObjectCacheTests* self) {
	Block11Data* _data11_;
	GMainLoop* _tmp0_;
	TestCache* _tmp1_;
	GeeHashSet* _tmp2_;
	GeeHashSet* obj_set;
	TestCache* _tmp12_;
	GeeHashSet* _tmp13_;
	GMainLoop* _tmp14_;
	TestCache* _tmp15_;
	GMainLoop* _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	GeeHashSet* _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_return_if_fail (self != NULL);
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data11_ = g_slice_new0 (Block11Data);
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data11_->_ref_count_ = 1;
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data11_->self = g_object_ref (self);
#line 484 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 484 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data11_->main_loop = _tmp0_;
#line 485 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = test_cache_new ("test-stress");
#line 485 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data11_->cache = _tmp1_;
#line 488 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data11_->obj_count = 66666;
#line 489 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = gee_hash_set_new (TYPE_TEST_OBJECT, (GBoxedCopyFunc) test_object_ref, test_object_unref, NULL, NULL);
#line 489 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	obj_set = _tmp2_;
#line 3213 "object-cache.c"
	{
		gint i;
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
		i = 0;
#line 3218 "object-cache.c"
		{
			gboolean _tmp3_;
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			_tmp3_ = TRUE;
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
			while (TRUE) {
#line 3225 "object-cache.c"
				gboolean _tmp4_;
				gint _tmp6_;
				gint _tmp7_;
				GeeHashSet* _tmp8_;
				gint _tmp9_;
				TestObject* _tmp10_;
				TestObject* _tmp11_;
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_tmp4_ = _tmp3_;
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				if (!_tmp4_) {
#line 3237 "object-cache.c"
					gint _tmp5_;
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					_tmp5_ = i;
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					i = _tmp5_ + 1;
#line 3243 "object-cache.c"
				}
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_tmp3_ = FALSE;
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_tmp6_ = i;
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_tmp7_ = _data11_->obj_count;
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				if (!(_tmp6_ < _tmp7_)) {
#line 491 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
					break;
#line 3255 "object-cache.c"
				}
#line 493 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_tmp8_ = obj_set;
#line 493 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_tmp9_ = i;
#line 493 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_tmp10_ = test_object_new ("bizzle", (guint) _tmp9_);
#line 493 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_tmp11_ = _tmp10_;
#line 493 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp8_, _tmp11_);
#line 493 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
				_test_object_unref0 (_tmp11_);
#line 3269 "object-cache.c"
			}
		}
	}
#line 497 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_test_timer_start ();
#line 499 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp12_ = _data11_->cache;
#line 499 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp13_ = obj_set;
#line 499 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_store_objects ((FolksObjectCache*) _tmp12_, (GeeSet*) _tmp13_, NULL, ___lambda21__gasync_ready_callback, block11_data_ref (_data11_));
#line 509 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp14_ = _data11_->main_loop;
#line 509 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_tmp14_);
#line 512 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_test_timer_start ();
#line 514 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data11_->new_obj_set = NULL;
#line 515 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp15_ = _data11_->cache;
#line 515 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	folks_object_cache_load_objects ((FolksObjectCache*) _tmp15_, NULL, ___lambda22__gasync_ready_callback, block11_data_ref (_data11_));
#line 525 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp16_ = _data11_->main_loop;
#line 525 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_main_loop_run (_tmp16_);
#line 529 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_data11_->new_obj_set != NULL);
#line 530 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp17_ = gee_collection_get_size ((GeeCollection*) _data11_->new_obj_set);
#line 530 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp18_ = _tmp17_;
#line 530 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp19_ = obj_set;
#line 530 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp20_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp19_);
#line 530 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp21_ = _tmp20_;
#line 530 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_assert (_tmp18_ == _tmp21_);
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (obj_set);
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	block11_data_unref (_data11_);
#line 482 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_data11_ = NULL;
#line 3317 "object-cache.c"
}


static void object_cache_tests_class_init (ObjectCacheTestsClass * klass) {
#line 58 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	object_cache_tests_parent_class = g_type_class_peek_parent (klass);
#line 58 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_type_class_add_private (klass, sizeof (ObjectCacheTestsPrivate));
#line 58 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = object_cache_tests_real_set_up;
#line 58 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = object_cache_tests_real_tear_down;
#line 58 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	G_OBJECT_CLASS (klass)->finalize = object_cache_tests_finalize;
#line 3332 "object-cache.c"
}


static void object_cache_tests_instance_init (ObjectCacheTests * self) {
#line 58 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self->priv = OBJECT_CACHE_TESTS_GET_PRIVATE (self);
#line 3339 "object-cache.c"
}


static void object_cache_tests_finalize (GObject* obj) {
	ObjectCacheTests * self;
#line 58 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	self = OBJECT_CACHE_TESTS (obj);
#line 60 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (self->priv->_cache_dir);
#line 58 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	G_OBJECT_CLASS (object_cache_tests_parent_class)->finalize (obj);
#line 3351 "object-cache.c"
}


GType object_cache_tests_get_type (void) {
	static volatile gsize object_cache_tests_type_id__volatile = 0;
	if (g_once_init_enter (&object_cache_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ObjectCacheTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) object_cache_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ObjectCacheTests), 0, (GInstanceInitFunc) object_cache_tests_instance_init, NULL };
		GType object_cache_tests_type_id;
		object_cache_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "ObjectCacheTests", &g_define_type_info, 0);
		g_once_init_leave (&object_cache_tests_type_id__volatile, object_cache_tests_type_id);
	}
	return object_cache_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	GTestSuite* _tmp0_ = NULL;
	GTestSuite* root;
	ObjectCacheTests* _tmp1_;
	ObjectCacheTests* _tmp2_;
	GTestSuite* _tmp3_ = NULL;
#line 536 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_test_init (&args_length1, &args, NULL);
#line 538 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp0_ = g_test_get_root ();
#line 538 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	root = _tmp0_;
#line 539 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp1_ = object_cache_tests_new ();
#line 539 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp2_ = _tmp1_;
#line 539 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_tmp3_ = folks_test_case_get_suite ((FolksTestCase*) _tmp2_);
#line 539 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_test_suite_add_suite (root, _tmp3_);
#line 539 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	_g_object_unref0 (_tmp2_);
#line 541 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_test_run ();
#line 543 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	result = 0;
#line 543 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return result;
#line 3396 "object-cache.c"
}


int main (int argc, char ** argv) {
#line 534 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	g_type_init ();
#line 534 "/opt/gnome2/source/folks/tests/folks/object-cache.vala"
	return _vala_main (argv, argc);
#line 3405 "object-cache.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



